@@ -21,8 +21,8 @@ class SelectionList:
                 properties = getattr(item, Key)
             if Selector.test(properties):
                 selection.append(item)
-        self.selection = selection
-        return self
+        sl = SelectionList(selection)
+        return sl
 
     def __iter__(self):
         return self.selection.__iter__()
